# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`libreswan`](#libreswan): Installs and configures libreswan to provide IPSEC capabilities.
* [`libreswan::config`](#libreswanconfig): Configures `ipsec.conf` and necessary directories.
* [`libreswan::config::firewall`](#libreswanconfigfirewall): Ensures that the required firewall rules are defined
* [`libreswan::config::pki`](#libreswanconfigpki): Ensure that the `simp/pki` PKI certificates are loaded into the IPSEC NSS Database.
* [`libreswan::config::pki::nsspki`](#libreswanconfigpkinsspki): Ensure that the PKI certificates are loaded into the NSS Database used by the IPSEC process.
* [`libreswan::install`](#libreswaninstall): Installs the appropriate packages.
* [`libreswan::service`](#libreswanservice): Ensure that the appropriate services are running.

### Defined types

* [`libreswan::connection`](#libreswanconnection): Create a connection file in the IPSEC configuration directory.
* [`libreswan::nss::init_db`](#libreswannssinit_db): Initializes the NSS database, sets the correct password, and configures FIPS if necessary.
* [`libreswan::nss::loadcacerts`](#libreswannssloadcacerts): Adds the CA certificates to the NSS trust store.
* [`libreswan::nss::loadcerts`](#libreswannssloadcerts): Load a server certificate into the NSS database.

### Data types

* [`Libreswan::ConnAddr`](#libreswanconnaddr): Valid libreswan connection addresses
* [`Libreswan::IP::V4::VirtualPrivate`](#libreswanipv4virtualprivate): Matches valid IPv4 CIDR Mask addresses Base Regex taken from Ruby core's Resolv::IPv4::Regex  Reference: ruby/lib/resolv.rb  Copyright 2010 T
* [`Libreswan::IP::V6::VirtualPrivate`](#libreswanipv6virtualprivate): Matches valid IPv4 CIDR Mask addresses Base Regex taken from Ruby core's Resolv::IPv4::Regex  Reference: ruby/lib/resolv.rb  Copyright 2010 T
* [`Libreswan::Interfaces`](#libreswaninterfaces): Valid libreswan interfaces
* [`Libreswan::VirtualPrivate`](#libreswanvirtualprivate): Valid virtual private addresses

## Classes

### <a name="libreswan"></a>`libreswan`

---
> It is very important you read the documentation that comes with libreswan
> before attempting to use this module.
---

---
> This module is designed to install and configure system IPSEC capabilities
> using libreswan.

> It will also configure and maintain the NSS database used by libreswan if you
> have chosen to let SIMP manage your PKI certificates.

> To add and start tunnels that will be managed by libreswan see the manifest
> `libreswan::add_connection`.
---

This module is optimally designed for use within a larger SIMP ecosystem, but
it can be used independently:

* When included within the SIMP ecosystem,
  security compliance settings will be managed from the Puppet server.

* If used independently, all SIMP-managed security subsystems are disabled by
  default, and must be explicitly opted into by administrators. Please review
  items referring to `simp_options::*` for additional information.

* See the libreswan documentation https://libreswan.org/man/ipsec.conf.5.html
  for more information regarding these variables.

* Any variable set to `undef` will not appear in the configuration file and
  will default to the value set by libreswan. Those set will appear in the
  configuration file but can be overwritten using Hiera.

* **See also**
  * https://libreswan.org

#### Parameters

The following parameters are available in the `libreswan` class:

* [`service_name`](#service_name)
* [`package_name`](#package_name)
* [`trusted_nets`](#trusted_nets)
* [`firewall`](#firewall)
* [`fips`](#fips)
* [`pki`](#pki)
* [`haveged`](#haveged)
* [`nssdb_password`](#nssdb_password)
* [`myid`](#myid)
* [`protostack`](#protostack)
* [`interfaces`](#interfaces)
* [`listen`](#listen)
* [`ikeport`](#ikeport)
* [`nflog_all`](#nflog_all)
* [`nat_ikeport`](#nat_ikeport)
* [`keep_alive`](#keep_alive)
* [`virtual_private`](#virtual_private)
* [`myvendorid`](#myvendorid)
* [`nhelpers`](#nhelpers)
* [`plutofork`](#plutofork)
* [`crlcheckinterval`](#crlcheckinterval)
* [`strictcrlpolicy`](#strictcrlpolicy)
* [`ocsp_enable`](#ocsp_enable)
* [`ocsp_strict`](#ocsp_strict)
* [`ocsp_timeout`](#ocsp_timeout)
* [`ocsp_uri`](#ocsp_uri)
* [`ocsp_trustname`](#ocsp_trustname)
* [`syslog`](#syslog)
* [`klipsdebug`](#klipsdebug)
* [`plutodebug`](#plutodebug)
* [`uniqueids`](#uniqueids)
* [`plutorestartoncrash`](#plutorestartoncrash)
* [`logfile`](#logfile)
* [`logappend`](#logappend)
* [`logtime`](#logtime)
* [`ddos_mode`](#ddos_mode)
* [`ddos_ike_treshold`](#ddos_ike_treshold)
* [`dumpdir`](#dumpdir)
* [`statsbin`](#statsbin)
* [`ipsecdir`](#ipsecdir)
* [`secretsfile`](#secretsfile)
* [`perpeerlog`](#perpeerlog)
* [`perpeerlogdir`](#perpeerlogdir)
* [`fragicmp`](#fragicmp)
* [`hidetos`](#hidetos)
* [`overridemtu`](#overridemtu)
* [`block_cidrs`](#block_cidrs)
* [`clear_cidrs`](#clear_cidrs)
* [`clear_private_cidrs`](#clear_private_cidrs)
* [`private_cidrs`](#private_cidrs)
* [`private_clear_cidrs`](#private_clear_cidrs)

##### <a name="service_name"></a>`service_name`

Data type: `String`

The name of the IPSEC service.

##### <a name="package_name"></a>`package_name`

Data type: `String`

The name of the libreswan package.

##### <a name="trusted_nets"></a>`trusted_nets`

Data type: `Simplib::Netlist`

An allowed set of subnetworks (in CIDR notataion) with permitted access
explicitly for IPSEC communication

Default value: `simplib::lookup('simp_options::trusted_nets', {'default_value' => ['127.0.0.1/32'] })`

##### <a name="firewall"></a>`firewall`

Data type: `Boolean`

Whether to add appropriate rules to allow IPSEC traffic to the
SIMP-controlled firewall

Default value: `simplib::lookup('simp_options::firewall', {'default_value' => false })`

##### <a name="fips"></a>`fips`

Data type: `Boolean`

Whether server is in FIPS mode.

* Affects cryptography allowed to be used by IPSEC.

Default value: `simplib::lookup('simp_options::fips', {'default_value' => false })`

##### <a name="pki"></a>`pki`

Data type: `Variant[Boolean,Enum['simp']]`

* If `'simp'`, include `simp/pki` and use `pki::copy` to manage application
  certs in `/etc/pki/simp_apps/libreswan/x509`
* If `true`, do *not* include `simp/pki`, but still use `pki::copy` to
  manage certs in `/etc/pki/simp_apps/libreswan/x509`
* If `false`, do *not* include `simp/pki` and do *not* use pki::copy to
  manage certs.  You will need to appropriately assign a subset of:
    * app_pki_dir
    * app_pki_key
    * app_pki_cert
    * app_pki_ca
    * app_pki_ca_dir

Default value: `simplib::lookup('simp_options::pki', {'default_value' => false })`

##### <a name="haveged"></a>`haveged`

Data type: `Boolean`

Whether to use haveged to ensure adequate entropy

Default value: `simplib::lookup('simp_options::haveged', {'default_value' => false })`

##### <a name="nssdb_password"></a>`nssdb_password`

Data type: `String`

Password for the NSS database used by ipsec

Default value: `simplib::passgen('nssdb_password')`

##### <a name="myid"></a>`myid`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="protostack"></a>`protostack`

Data type: `Enum['netkey','klips','mast']`



Default value: `'netkey'`

##### <a name="interfaces"></a>`interfaces`

Data type: `Optional[Libreswan::Interfaces]`



Default value: ``undef``

##### <a name="listen"></a>`listen`

Data type: `Optional[Simplib::IP]`



Default value: ``undef``

##### <a name="ikeport"></a>`ikeport`

Data type: `Simplib::Port`

DEPRECATED

Default value: `500`

##### <a name="nflog_all"></a>`nflog_all`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="nat_ikeport"></a>`nat_ikeport`

Data type: `Simplib::Port`

DEPRECATED

Default value: `4500`

##### <a name="keep_alive"></a>`keep_alive`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="virtual_private"></a>`virtual_private`

Data type: `Libreswan::VirtualPrivate`



Default value: `['%v4:10.0.0.0/8','%v4:192.168.0.0/16','%v4:172.16.0.0/12']`

##### <a name="myvendorid"></a>`myvendorid`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="nhelpers"></a>`nhelpers`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="plutofork"></a>`plutofork`

Data type: `Optional[Enum['yes','no']]`



Default value: ``undef``

##### <a name="crlcheckinterval"></a>`crlcheckinterval`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="strictcrlpolicy"></a>`strictcrlpolicy`

Data type: `Optional[Enum['yes','no']]`



Default value: ``undef``

##### <a name="ocsp_enable"></a>`ocsp_enable`

Data type: `Optional[Enum['yes','no']]`



Default value: ``undef``

##### <a name="ocsp_strict"></a>`ocsp_strict`

Data type: `Optional[Enum['yes','no']]`



Default value: ``undef``

##### <a name="ocsp_timeout"></a>`ocsp_timeout`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="ocsp_uri"></a>`ocsp_uri`

Data type: `Optional[Simplib::Uri]`



Default value: ``undef``

##### <a name="ocsp_trustname"></a>`ocsp_trustname`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="syslog"></a>`syslog`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="klipsdebug"></a>`klipsdebug`

Data type: `String`

DEPRECATED

Default value: `'none'`

##### <a name="plutodebug"></a>`plutodebug`

Data type: `String`



Default value: `'none'`

##### <a name="uniqueids"></a>`uniqueids`

Data type: `Optional[Enum['yes','no']]`



Default value: ``undef``

##### <a name="plutorestartoncrash"></a>`plutorestartoncrash`

Data type: `Optional[Enum['yes','no']]`



Default value: ``undef``

##### <a name="logfile"></a>`logfile`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="logappend"></a>`logappend`

Data type: `Optional[Enum['yes','no']]`



Default value: ``undef``

##### <a name="logtime"></a>`logtime`

Data type: `Optional[Enum['yes','no']]`



Default value: ``undef``

##### <a name="ddos_mode"></a>`ddos_mode`

Data type: `Optional[Enum['busy',
    'unlimited','auto']]`



Default value: ``undef``

##### <a name="ddos_ike_treshold"></a>`ddos_ike_treshold`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="dumpdir"></a>`dumpdir`

Data type: `Stdlib::Absolutepath`



Default value: `'/var/run/pluto'`

##### <a name="statsbin"></a>`statsbin`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ipsecdir"></a>`ipsecdir`

Data type: `Stdlib::Absolutepath`

The directory to store all ipsec configuration information.

Default value: `'/etc/ipsec.d'`

##### <a name="secretsfile"></a>`secretsfile`

Data type: `Stdlib::Absolutepath`



Default value: `'/etc/ipsec.secrets'`

##### <a name="perpeerlog"></a>`perpeerlog`

Data type: `Optional[Enum['yes','no']]`

DEPRECATED

Default value: ``undef``

##### <a name="perpeerlogdir"></a>`perpeerlogdir`

Data type: `Stdlib::Absolutepath`

DEPRECATED

Default value: `'/var/log/pluto/peer'`

##### <a name="fragicmp"></a>`fragicmp`

Data type: `Optional[Enum['yes','no']]`



Default value: ``undef``

##### <a name="hidetos"></a>`hidetos`

Data type: `Optional[Enum['yes','no']]`



Default value: ``undef``

##### <a name="overridemtu"></a>`overridemtu`

Data type: `Optional[Integer]`



Default value: ``undef``

##### <a name="block_cidrs"></a>`block_cidrs`

Data type: `Optional[Array[Simplib::IP::V4::CIDR]]`

List of CIDRs to which communication should never be allowed

Default value: ``undef``

##### <a name="clear_cidrs"></a>`clear_cidrs`

Data type: `Optional[Array[Simplib::IP::V4::CIDR]]`

List of CIDRs to which communication should always be in the clear

Default value: ``undef``

##### <a name="clear_private_cidrs"></a>`clear_private_cidrs`

Data type: `Optional[Array[Simplib::IP::V4::CIDR]]`

List of CIDRs to which communication will be in the clear, or, if the other
side initiates IPSEC, use encryption

Default value: ``undef``

##### <a name="private_cidrs"></a>`private_cidrs`

Data type: `Optional[Array[Simplib::IP::V4::CIDR]]`

List of CIDRs to which communication should always be private

Default value: ``undef``

##### <a name="private_clear_cidrs"></a>`private_clear_cidrs`

Data type: `Optional[Array[Simplib::IP::V4::CIDR]]`

List of CIDRs to which communication should be private if possible but in
the clear otherwise

Default value: `['0.0.0.0/0']`

### <a name="libreswanconfig"></a>`libreswan::config`

Configures `ipsec.conf` and necessary directories.

### <a name="libreswanconfigfirewall"></a>`libreswan::config::firewall`

Ensures that the required firewall rules are defined

### <a name="libreswanconfigpki"></a>`libreswan::config::pki`

Ensure that the `simp/pki` PKI certificates are loaded into the IPSEC NSS Database.

#### Parameters

The following parameters are available in the `libreswan::config::pki` class:

* [`app_pki_external_source`](#app_pki_external_source)
* [`app_pki_dir`](#app_pki_dir)
* [`app_pki_key`](#app_pki_key)
* [`app_pki_cert`](#app_pki_cert)
* [`app_pki_ca`](#app_pki_ca)

##### <a name="app_pki_external_source"></a>`app_pki_external_source`

Data type: `String`

* If `$pki` = `'simp'` or `true`, this is the directory from which certs
will be copied, via `pki::copy`.
* If `$pki` = `false`, this variable has no effect.

Default value: `simplib::lookup('simp_options::pki::source', { 'default_value' => '/etc/pki/simp/x509' })`

##### <a name="app_pki_dir"></a>`app_pki_dir`

Data type: `Stdlib::Absolutepath`

Controls the base path of the other `app_pki_*` parameters.

Default value: `'/etc/pki/simp_apps/libreswan/x509'`

##### <a name="app_pki_key"></a>`app_pki_key`

Data type: `Stdlib::Absolutepath`

Path and name of the private SSL key file

Default value: `"${app_pki_dir}/private/${::fqdn}.pem"`

##### <a name="app_pki_cert"></a>`app_pki_cert`

Data type: `Stdlib::Absolutepath`

Path and name of the public SSL certificate

Default value: `"${app_pki_dir}/public/${::fqdn}.pub"`

##### <a name="app_pki_ca"></a>`app_pki_ca`

Data type: `Stdlib::Absolutepath`

Path and name of the CA.

Default value: `"${app_pki_dir}/cacerts/cacerts.pem"`

### <a name="libreswanconfigpkinsspki"></a>`libreswan::config::pki::nsspki`

Called when the certificates change or when the database is initialized.

#### Parameters

The following parameters are available in the `libreswan::config::pki::nsspki` class:

* [`certname`](#certname)

##### <a name="certname"></a>`certname`

Data type: `String[1]`

The name of the certificate to be used

Default value: `$facts['fqdn']`

### <a name="libreswaninstall"></a>`libreswan::install`

Installs the appropriate packages.

### <a name="libreswanservice"></a>`libreswan::service`

Ensure that the appropriate services are running.

## Defined types

### <a name="libreswanconnection"></a>`libreswan::connection`

You can can set up defaults for all of your connections by using the name
'default'. This will create a file `default.conf` with a `'conn %default'`
header.  Then, all settings in default.conf will be used as defaults for
connections specified in other files.

Not all available, connection-related, libreswan settings are defined
here. However, should you need a missing setting you can manually
create a correctly-formatted, connection configuration file in the
IPSEC configuration directory.  This file must have a `.conf` suffix.

* Manually generated configuration files are not managed, or purged, by Puppet.

The following parameters correspond to libreswan settings for which
the default values are different from the libreswan defaults. You
can override the defaults by passing in different data in the
definition parameters.

The rest of the parameters map one-to-one to libreswan settings and
are `undef`.

Any `undef` parameter will not appear in the generated configuration file for
the connection. See libreswan documentation for the setting defaults when
omitted from a connection's configuration.
https://libreswan.org/man/ipsec.conf.5.html, the `CONN:SETTINGS` section

#### Parameters

The following parameters are available in the `libreswan::connection` defined type:

* [`dir`](#dir)
* [`keyingtries`](#keyingtries)
* [`ike`](#ike)
* [`phase2alg`](#phase2alg)
* [`left`](#left)
* [`right`](#right)
* [`connaddrfamily`](#connaddrfamily)
* [`leftaddresspool`](#leftaddresspool)
* [`leftsubnet`](#leftsubnet)
* [`leftsubnets`](#leftsubnets)
* [`leftprotoport`](#leftprotoport)
* [`leftsourceip`](#leftsourceip)
* [`leftupdown`](#leftupdown)
* [`leftcert`](#leftcert)
* [`leftrsasigkey`](#leftrsasigkey)
* [`leftrsasigkey2`](#leftrsasigkey2)
* [`leftsendcert`](#leftsendcert)
* [`leftnexthop`](#leftnexthop)
* [`leftid`](#leftid)
* [`leftca`](#leftca)
* [`rightid`](#rightid)
* [`rightrsasigkey`](#rightrsasigkey)
* [`rightrsasigkey2`](#rightrsasigkey2)
* [`rightca`](#rightca)
* [`rightaddresspool`](#rightaddresspool)
* [`rightsubnets`](#rightsubnets)
* [`rightsubnet`](#rightsubnet)
* [`rightprotoport`](#rightprotoport)
* [`rightsourceip`](#rightsourceip)
* [`rightupdown`](#rightupdown)
* [`rightcert`](#rightcert)
* [`rightsendcert`](#rightsendcert)
* [`rightnexthop`](#rightnexthop)
* [`auto`](#auto)
* [`authby`](#authby)
* [`type`](#type)
* [`ikev2`](#ikev2)
* [`mobike`](#mobike)
* [`phase2`](#phase2)
* [`ikepad`](#ikepad)
* [`fragmentation`](#fragmentation)
* [`sha2_truncbug`](#sha2_truncbug)
* [`narrowing`](#narrowing)
* [`sareftrack`](#sareftrack)
* [`leftxauthserver`](#leftxauthserver)
* [`rightxauthserver`](#rightxauthserver)
* [`leftxauthusername`](#leftxauthusername)
* [`rightxauthusername`](#rightxauthusername)
* [`leftxauthclient`](#leftxauthclient)
* [`rightxauthclient`](#rightxauthclient)
* [`leftmodecfgserver`](#leftmodecfgserver)
* [`rightmodecfgserver`](#rightmodecfgserver)
* [`leftmodecfgclient`](#leftmodecfgclient)
* [`rightmodecfgclient`](#rightmodecfgclient)
* [`xauthby`](#xauthby)
* [`xauthfail`](#xauthfail)
* [`modecfgpull`](#modecfgpull)
* [`modecfgdns`](#modecfgdns)
* [`modecfgdns1`](#modecfgdns1)
* [`modecfgdns2`](#modecfgdns2)
* [`modecfgdomain`](#modecfgdomain)
* [`modecfgdomains`](#modecfgdomains)
* [`modecfgbanner`](#modecfgbanner)
* [`nat_ikev1_method`](#nat_ikev1_method)
* [`dpddelay`](#dpddelay)
* [`dpdtimeout`](#dpdtimeout)
* [`dpdaction`](#dpdaction)

##### <a name="dir"></a>`dir`

Data type: `Stdlib::Absolutepath`

The absolute path to the IPSEC configuration directory.

Default value: `'/etc/ipsec.d'`

##### <a name="keyingtries"></a>`keyingtries`

Data type: `Integer`

The number of times a connection will try to reconnect before exiting.

Default value: `10`

##### <a name="ike"></a>`ike`

Data type: `String`

The ciphers used in the connection.

Default value: `'aes-sha2'`

##### <a name="phase2alg"></a>`phase2alg`

Data type: `String`

The ciphers used in the second part of the connection.

Default value: `'aes-sha2'`

##### <a name="left"></a>`left`

Data type: `Optional[Libreswan::ConnAddr]`



Default value: ``undef``

##### <a name="right"></a>`right`

Data type: `Optional[Libreswan::ConnAddr]`



Default value: ``undef``

##### <a name="connaddrfamily"></a>`connaddrfamily`

Data type: `Optional[Enum['ipv4','ipv6']]`



Default value: ``undef``

##### <a name="leftaddresspool"></a>`leftaddresspool`

Data type: `Optional[Array[Simplib::IP,2,2]]`



Default value: ``undef``

##### <a name="leftsubnet"></a>`leftsubnet`

Data type: `Optional[Variant[
    Enum['%no','%priv'],
    Pattern['^vhost:*'],
    Pattern['^vnet:*'],
    Simplib::IP::CIDR]]`



Default value: ``undef``

##### <a name="leftsubnets"></a>`leftsubnets`

Data type: `Optional[Array[Simplib::IP::CIDR]]`



Default value: ``undef``

##### <a name="leftprotoport"></a>`leftprotoport`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="leftsourceip"></a>`leftsourceip`

Data type: `Optional[Simplib::IP]`



Default value: ``undef``

##### <a name="leftupdown"></a>`leftupdown`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="leftcert"></a>`leftcert`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="leftrsasigkey"></a>`leftrsasigkey`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="leftrsasigkey2"></a>`leftrsasigkey2`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="leftsendcert"></a>`leftsendcert`

Data type: `Optional[Enum['yes', 'no',
    'never','always','sendifasked']]`



Default value: ``undef``

##### <a name="leftnexthop"></a>`leftnexthop`

Data type: `Optional[Variant[
    Enum['%direct','%defaultroute'],
    Simplib::IP]]`



Default value: ``undef``

##### <a name="leftid"></a>`leftid`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="leftca"></a>`leftca`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="rightid"></a>`rightid`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="rightrsasigkey"></a>`rightrsasigkey`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="rightrsasigkey2"></a>`rightrsasigkey2`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="rightca"></a>`rightca`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="rightaddresspool"></a>`rightaddresspool`

Data type: `Optional[Array[Simplib::IP,2,2]]`



Default value: ``undef``

##### <a name="rightsubnets"></a>`rightsubnets`

Data type: `Optional[Array[Simplib::IP::CIDR]]`



Default value: ``undef``

##### <a name="rightsubnet"></a>`rightsubnet`

Data type: `Optional[Variant[
    Enum['%no','%priv'],
    Pattern['^vhost:*'],
    Pattern['^vnet:*'],
    Simplib::IP::CIDR]]`



Default value: ``undef``

##### <a name="rightprotoport"></a>`rightprotoport`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="rightsourceip"></a>`rightsourceip`

Data type: `Optional[Simplib::IP]`



Default value: ``undef``

##### <a name="rightupdown"></a>`rightupdown`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="rightcert"></a>`rightcert`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="rightsendcert"></a>`rightsendcert`

Data type: `Optional[Enum['yes', 'no',
    'never','always','sendifasked']]`



Default value: ``undef``

##### <a name="rightnexthop"></a>`rightnexthop`

Data type: `Optional[Variant[
    Enum['%direct','%defaultroute'],
    Simplib::IP]]`



Default value: ``undef``

##### <a name="auto"></a>`auto`

Data type: `Optional[Enum['add','start',
    'ondemand', 'ignore']]`



Default value: ``undef``

##### <a name="authby"></a>`authby`

Data type: `Optional[Enum['rsasig','secret',
    'secret|rsasig', 'never', 'null']]`



Default value: ``undef``

##### <a name="type"></a>`type`

Data type: `Optional[Enum['tunnel','transport',
    'passthough','reject','drop']]`



Default value: ``undef``

##### <a name="ikev2"></a>`ikev2`

Data type: `Optional[Enum['insist','permit',
    'propose','never','yes', 'no']]`



Default value: ``undef``

##### <a name="mobike"></a>`mobike`

Data type: `Optional[Enum['yes', 'no']]`



Default value: ``undef``

##### <a name="phase2"></a>`phase2`

Data type: `Optional[Enum['esp', 'ah']]`



Default value: ``undef``

##### <a name="ikepad"></a>`ikepad`

Data type: `Optional[Enum['yes','no']]`



Default value: ``undef``

##### <a name="fragmentation"></a>`fragmentation`

Data type: `Optional[Enum['yes','no','force']]`



Default value: ``undef``

##### <a name="sha2_truncbug"></a>`sha2_truncbug`

Data type: `Optional[Enum['yes','no']]`



Default value: ``undef``

##### <a name="narrowing"></a>`narrowing`

Data type: `Optional[Enum['yes','no']]`



Default value: ``undef``

##### <a name="sareftrack"></a>`sareftrack`

Data type: `Optional[Enum['yes','no',
    'conntrack']]`



Default value: ``undef``

##### <a name="leftxauthserver"></a>`leftxauthserver`

Data type: `Optional[Enum['yes','no']]`



Default value: ``undef``

##### <a name="rightxauthserver"></a>`rightxauthserver`

Data type: `Optional[Enum['yes','no']]`



Default value: ``undef``

##### <a name="leftxauthusername"></a>`leftxauthusername`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="rightxauthusername"></a>`rightxauthusername`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="leftxauthclient"></a>`leftxauthclient`

Data type: `Optional[Enum['yes','no']]`



Default value: ``undef``

##### <a name="rightxauthclient"></a>`rightxauthclient`

Data type: `Optional[Enum['yes','no']]`



Default value: ``undef``

##### <a name="leftmodecfgserver"></a>`leftmodecfgserver`

Data type: `Optional[Enum['yes','no']]`



Default value: ``undef``

##### <a name="rightmodecfgserver"></a>`rightmodecfgserver`

Data type: `Optional[Enum['yes','no']]`



Default value: ``undef``

##### <a name="leftmodecfgclient"></a>`leftmodecfgclient`

Data type: `Optional[Enum['yes','no']]`



Default value: ``undef``

##### <a name="rightmodecfgclient"></a>`rightmodecfgclient`

Data type: `Optional[Enum['yes','no']]`



Default value: ``undef``

##### <a name="xauthby"></a>`xauthby`

Data type: `Optional[Enum['file','pam',
    'alwaysok']]`



Default value: ``undef``

##### <a name="xauthfail"></a>`xauthfail`

Data type: `Optional[Enum['hard','soft']]`



Default value: ``undef``

##### <a name="modecfgpull"></a>`modecfgpull`

Data type: `Optional[Enum['yes','no']]`



Default value: ``undef``

##### <a name="modecfgdns"></a>`modecfgdns`

Data type: `Optional[Array[Simplib::IP]]`

Support 3.23+ DNS configuration

Default value: ``undef``

##### <a name="modecfgdns1"></a>`modecfgdns1`

Data type: `Optional[Simplib::IP]`

Support <= 3.22 domain configuration

Default value: ``undef``

##### <a name="modecfgdns2"></a>`modecfgdns2`

Data type: `Optional[Simplib::IP]`

Support <= 3.22 domain configuration

Default value: ``undef``

##### <a name="modecfgdomain"></a>`modecfgdomain`

Data type: `Optional[String]`

Support <= 3.22 domain configuration

Default value: ``undef``

##### <a name="modecfgdomains"></a>`modecfgdomains`

Data type: `Optional[Array[String]]`

Support 3.23+ domains configuration

Default value: ``undef``

##### <a name="modecfgbanner"></a>`modecfgbanner`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="nat_ikev1_method"></a>`nat_ikev1_method`

Data type: `Optional[Enum['drafts','rfc',
    'both']]`



Default value: ``undef``

##### <a name="dpddelay"></a>`dpddelay`

Data type: `Optional[Pattern[/\d+[smh]$/]]`



Default value: ``undef``

##### <a name="dpdtimeout"></a>`dpdtimeout`

Data type: `Optional[Pattern[/\d+[smh]$/]]`



Default value: ``undef``

##### <a name="dpdaction"></a>`dpdaction`

Data type: `Optional[Enum['hold', 'clear',
    'restart']]`



Default value: ``undef``

### <a name="libreswannssinit_db"></a>`libreswan::nss::init_db`

Initializes the NSS database, sets the correct password, and configures FIPS if necessary.

#### Parameters

The following parameters are available in the `libreswan::nss::init_db` defined type:

* [`dbdir`](#dbdir)
* [`password`](#password)
* [`destroyexisting`](#destroyexisting)
* [`fips`](#fips)
* [`token`](#token)
* [`nsspassword`](#nsspassword)

##### <a name="dbdir"></a>`dbdir`

Data type: `Stdlib::Absolutepath`

Directory where the NSS database will be created.

##### <a name="password"></a>`password`

Data type: `String`

Password used to protect the database.

* Each NSS database is broken up into tokens used for different types of
certificates, Smart cards, FIPS compliant, non-FIPS. This util sets the
FIPS and non-FIPS token to they same password.  The tokens are defined by
`$libreswan::nsstoken`. You can add tokens to array if there are other
parts of the database you want to protect.

##### <a name="destroyexisting"></a>`destroyexisting`

Data type: `Boolean`

If true, it will remove the existing database before running the init command.

Default value: ``false``

##### <a name="fips"></a>`fips`

Data type: `Boolean`



Default value: `simplib::lookup('simp_options::fips', { 'default_value' => false})`

##### <a name="token"></a>`token`

Data type: `String`



Default value: `'NSS Certificate DB'`

##### <a name="nsspassword"></a>`nsspassword`

Data type: `Stdlib::Absolutepath`



Default value: `"${dbdir}/nsspassword"`

### <a name="libreswannssloadcacerts"></a>`libreswan::nss::loadcacerts`

Adds the CA certificates to the NSS trust store.

#### Parameters

The following parameters are available in the `libreswan::nss::loadcacerts` defined type:

* [`dbdir`](#dbdir)
* [`nsspwd_file`](#nsspwd_file)
* [`cert`](#cert)
* [`token`](#token)
* [`certtype`](#certtype)

##### <a name="dbdir"></a>`dbdir`

Data type: `Stdlib::Absolutepath`

The directory where the DB is located

##### <a name="nsspwd_file"></a>`nsspwd_file`

Data type: `Stdlib::Absolutepath`



Default value: `"${dbdir}/nsspassword"`

##### <a name="cert"></a>`cert`

Data type: `Stdlib::Absolutepath`

The absolute path to the public portion CA certificate.

##### <a name="token"></a>`token`

Data type: `String`



Default value: `'NSS Certificate DB'`

##### <a name="certtype"></a>`certtype`

Data type: `Enum['PEM','DER']`

The format the certificate is in. PEM and DER are currently acceptable.

Default value: `'PEM'`

### <a name="libreswannssloadcerts"></a>`libreswan::nss::loadcerts`

Load a server certificate into the NSS database.

#### Parameters

The following parameters are available in the `libreswan::nss::loadcerts` defined type:

* [`dbdir`](#dbdir)
* [`nsspwd_file`](#nsspwd_file)
* [`cert`](#cert)
* [`token`](#token)
* [`key`](#key)
* [`certtype`](#certtype)

##### <a name="dbdir"></a>`dbdir`

Data type: `Stdlib::Absolutepath`

The directory where the NSS Database is located.

##### <a name="nsspwd_file"></a>`nsspwd_file`

Data type: `Stdlib::Absolutepath`

The file which contains the password if there is one.

Default value: `"${dbdir}/nsspassword"`

##### <a name="cert"></a>`cert`

Data type: `Stdlib::Absolutepath`

The absolute path to the public portion of the cert.

##### <a name="token"></a>`token`

Data type: `String`



Default value: `'NSS Certificate DB'`

##### <a name="key"></a>`key`

Data type: `Optional[Stdlib::Absolutepath]`

The absolute path to the private portion of the cert.

Default value: ``undef``

##### <a name="certtype"></a>`certtype`

Data type: `Enum['PEM','P12']`

The format the certificate is in.

Default value: `'PEM'`

## Data types

### <a name="libreswanconnaddr"></a>`Libreswan::ConnAddr`

Valid libreswan connection addresses

Alias of

```puppet
Variant[Enum[
    '%any',
    '%defaultroute',
    '%opportunistic',
    '%opportunisticgroup',
    '%group'
  ], Simplib::IP::V4, Simplib::IP::V6, Pattern['^%[a-zA-Z]+\d+$']]
```

### <a name="libreswanipv4virtualprivate"></a>`Libreswan::IP::V4::VirtualPrivate`

Matches valid IPv4 CIDR Mask addresses
Base Regex taken from Ruby core's Resolv::IPv4::Regex

Reference: ruby/lib/resolv.rb

Copyright 2010 Tanaka Akira <kr@fsij.org>
Released under the guidance of the Ruby COPYING file section 2(a)
Commit 4e3a98d383eb3c420df5208d83f9aba70b504e33

Alias of

```puppet
Pattern['^(?-mix:\A%v4:(!)?((?x-mi:0|1(?:[0-9][0-9]?)?|2(?:[0-4][0-9]?|5[0-5]?|[6-9])?|[3-9][0-9]?))\.((?x-mi:0|1(?:[0-9][0-9]?)?|2(?:[0-4][0-9]?|5[0-5]?|[6-9])?|[3-9][0-9]?))\.((?x-mi:0|1(?:[0-9][0-9]?)?|2(?:[0-4][0-9]?|5[0-5]?|[6-9])?|[3-9][0-9]?))\.((?x-mi:0|1(?:[0-9][0-9]?)?|2(?:[0-4][0-9]?|5[0-5]?|[6-9])?|[3-9][0-9]?))/(3[012]|[12][0-9]|[0-9])\z)$']
```

### <a name="libreswanipv6virtualprivate"></a>`Libreswan::IP::V6::VirtualPrivate`

Matches valid IPv4 CIDR Mask addresses
Base Regex taken from Ruby core's Resolv::IPv4::Regex

Reference: ruby/lib/resolv.rb

Copyright 2010 Tanaka Akira <kr@fsij.org>
Released under the guidance of the Ruby COPYING file section 2(a)
Commit 4e3a98d383eb3c420df5208d83f9aba70b504e33

Alias of

```puppet
Pattern['^(?x-mi:(\A%v6:(!)?(?x-mi:(?:(?x-mi:(?:[0-9A-Fa-f]{1,4}:){7}[0-9A-Fa-f]{1,4}/(12[0-8]|1[01][0-9]|[0-9]?[0-9])\z))|(?:(?x-mi:((?:[0-9A-Fa-f]{1,4}(?::[0-9A-Fa-f]{1,4})*)?)::((?:[0-9A-Fa-f]{1,4}(?::[0-9A-Fa-f]{1,4})*)?)/(12[0-8]|1[01][0-9]|[0-9]?[0-9])\z))|(?:(?x-mi:((?:[0-9A-Fa-f]{1,4}:){6,6})(\d+)\.(\d+)\.(\d+)\.(\d+)/(12[0-8]|1[01][0-9]|[0-9]?[0-9])\z))|(?:(?x-mi:((?:[0-9A-Fa-f]{1,4}(?::[0-9A-Fa-f]{1,4})*)?)::((?:[0-9A-Fa-f]{1,4}:)*)(\d+)\.(\d+)\.(\d+)\.(\d+)/(12[0-8]|1[01][0-9]|[0-9]?[0-9]))))\z))$']
```

### <a name="libreswaninterfaces"></a>`Libreswan::Interfaces`

Valid libreswan interfaces

Alias of

```puppet
Array[Variant[
    Enum['%none','%defaultroute'],
    Pattern['(\w+=\w+)']
  ]]
```

### <a name="libreswanvirtualprivate"></a>`Libreswan::VirtualPrivate`

Valid virtual private addresses

Alias of

```puppet
Array[Variant[
    Libreswan::IP::V4::VirtualPrivate,
    Libreswan::IP::V6::VirtualPrivate
  ]]
```

